@@ -4,8 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 use smallnum;
-use Anonymous::Object;
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 our (%TOOL, $ANOBJECT);
 
@@ -14,9 +13,6 @@ use overload
 
 
 BEGIN {
-	$ANOBJECT = Anonymous::Object->new({
-		object_name => 'Colouring::In'
-	});
 	%TOOL = (
 		clamp => sub { return $TOOL{min}( $TOOL{max}( $_[0], 0 ), $_[1]); },
 		max => sub { $_[ ($_[0] || 0) < ($_[1] || 0) ] || 0 },
@@ -392,18 +388,18 @@ sub validate {
 	my ($self, $colour) = @_;
 	my $new = eval { $self->new($colour) };
 	if ($@) {
-		return $ANOBJECT->hash_to_object({
+		return {
 			valid => \0,
 			message => $TOOL{MESSAGES}{VALIDATE_ERROR} || 'The string passed to Colouring::In::validate is not a valid color.',
 			color => $colour
-		});
+		};
 	}
-	return $ANOBJECT->hash_to_object({
+	return {
 		valid => \1,
 		message => $TOOL{MESSAGES}{VALIDATE} || 'The string passed to Colouring::In::validate is a valid color',
 		color => $colour,
 		colour => $new
-	});
+	};
 }
 
 1;
@@ -416,7 +412,7 @@ Colouring::In - color or colour.
 
 =head1 VERSION
 
-Version 0.21
+Version 0.22
 
 =cut
 
